@@ -8,7 +8,7 @@ except ImportError:
     from io import StringIO
 
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 
 def format_code(source):
@@ -17,6 +17,7 @@ def format_code(source):
     formatted = ''
     previous_token_string = ''
     previous_token_type = None
+    previous_line = ''
     last_row = 0
     last_column = -1
     for token in tokenize.generate_tokens(sio.readline):
@@ -25,6 +26,11 @@ def format_code(source):
         start_row, start_column = token[2]
         end_row, end_column = token[3]
 
+        # Preserve escaped newlines
+        if (start_row > last_row and
+                previous_line.endswith('\\\n')):
+            formatted += previous_line[len(previous_line.rstrip(' \t\n\r\\')):]
+
         if start_row > last_row:
             last_column = 0
         if start_column > last_column:
@@ -39,6 +45,7 @@ def format_code(source):
 
         previous_token_string = token_string
         previous_token_type = token_type
+        previous_line = token[4]
 
         last_row = end_row
         last_column = end_column
@@ -67,7 +74,7 @@ def format_docstring(indentation, docstring):
 {indentation}"""\
 '''.format(summary=normalize_summary(summary),
            description='\n'.join([indent_non_indented(l, indentation).rstrip()
-                                  for l in description.split('\n')]),
+                                  for l in description.splitlines()]),
            indentation=indentation)
     else:
         return '"""' + normalize_summary(contents) + '"""'
@@ -87,7 +94,7 @@ def split_summary_and_description(contents):
     Return tuple (summary, description).
 
     """
-    split = contents.split('\n')
+    split = contents.splitlines()
     if len(split) > 1 and not split[1].strip():
         return (split[0], '\n'.join(split[2:]))
     else:
@@ -149,8 +156,8 @@ def main(argv, output_file):
         else:
             import difflib
             diff = difflib.unified_diff(
-                    [l + '\n' for l in source.split('\n')],
-                    [l + '\n' for l in formatted_source.split('\n')],
+                    source.splitlines(True),
+                    formatted_source.splitlines(True),
                     'before/' + filename,
                     'after/' + filename)
             output_file.write(''.join(diff))
